(examples)=
# Examples

```{toctree}
:maxdepth: 1

examples/basic output example
examples/complex output example
examples/farming example
examples/crop example
examples/dask distributed example
examples/visualize linear algebra
```
